@@ -1,8 +1,8 @@
 package Module::Build::Config;
 
 use strict;
-use warnings;
-our $VERSION = '0.42_35';
+use vars qw($VERSION);
+$VERSION = '0.2808_01';
 $VERSION = eval $VERSION;
 use Config;
 
