@@ -1,10 +1,8 @@
 package Module::Build::PPMMaker;
 
 use strict;
-use warnings;
-use Config;
-
-our $VERSION = '0.42_35';
+use vars qw($VERSION);
+$VERSION = '0.2808_01';
 $VERSION = eval $VERSION;
 
 # This code is mostly borrowed from ExtUtils::MM_Unix 6.10_03, with a
@@ -36,6 +34,7 @@ sub make_ppd {
     my $method = "dist_$info";
     $dist{$info} = $build->$method() or die "Can't determine distribution's $info\n";
   }
+  $dist{version} = $self->_ppd_version($dist{version});
 
   $self->_simple_xml_escape($_) foreach $dist{abstract}, @{$dist{author}};
 
@@ -43,24 +42,28 @@ sub make_ppd {
   # various licenses
   my $ppd = <<"PPD";
 <SOFTPKG NAME=\"$dist{name}\" VERSION=\"$dist{version}\">
+    <TITLE>$dist{name}</TITLE>
     <ABSTRACT>$dist{abstract}</ABSTRACT>
 @{[ join "\n", map "    <AUTHOR>$_</AUTHOR>", @{$dist{author}} ]}
     <IMPLEMENTATION>
 PPD
 
+  # TODO: We could set <IMPLTYPE VALUE="PERL" /> or maybe
+  # <IMPLTYPE VALUE="PERL/XS" /> ???
+
   # We don't include recommended dependencies because PPD has no way
   # to distinguish them from normal dependencies.  We don't include
   # build_requires dependencies because the PPM installer doesn't
   # build or test before installing.  And obviously we don't include
   # conflicts either.
-
+  
   foreach my $type (qw(requires)) {
     my $prereq = $build->$type();
-    foreach my $modname (sort keys %$prereq) {
+    while (my ($modname, $spec) = each %$prereq) {
       next if $modname eq 'perl';
 
       my $min_version = '0.0';
-      foreach my $c ($build->_parse_conditions($prereq->{$modname})) {
+      foreach my $c ($build->_parse_conditions($spec)) {
         my ($op, $version) = $c =~ /^\s*  (<=?|>=?|==|!=)  \s*  ([\w.]+)  \s*$/x;
 
         # This is a nasty hack because it fails if there is no >= op
@@ -70,18 +73,27 @@ PPD
         }
       }
 
-      # PPM4 spec requires a '::' for top level modules
-      $modname .= '::' unless $modname =~ /::/;
+      # Another hack - dependencies are on modules, but PPD expects
+      # them to be on distributions (I think).
+      $modname =~ s/::/-/g;
+
+      $ppd .= sprintf(<<'EOF', $modname, $self->_ppd_version($min_version));
+        <DEPENDENCY NAME="%s" VERSION="%s" />
+EOF
 
-      $ppd .= qq!        <REQUIRE NAME="$modname" VERSION="$min_version" />\n!;
     }
   }
 
   # We only include these tags if this module involves XS, on the
-  # assumption that pure Perl modules will work on any OS.
+  # assumption that pure Perl modules will work on any OS.  PERLCORE,
+  # unfortunately, seems to indicate that a module works with _only_
+  # that version of Perl, and so is only appropriate when a module
+  # uses XS.
   if (keys %{$build->find_xs_files}) {
     my $perl_version = $self->_ppd_version($build->perl_version);
-    $ppd .= sprintf(<<'EOF', $self->_varchname($build->config) );
+    $ppd .= sprintf(<<'EOF', $perl_version, $^O, $self->_varchname($build->config) );
+        <PERLCORE VERSION="%s" />
+        <OS NAME="%s" />
         <ARCHITECTURE NAME="%s" />
 EOF
   }
@@ -99,11 +111,8 @@ EOF
 EOF
 
   my $ppd_file = "$dist{name}.ppd";
-  open(my $fh, '>', $ppd_file)
+  my $fh = IO::File->new(">$ppd_file")
     or die "Cannot write to $ppd_file: $!";
-
-  binmode($fh, ":utf8")
-    if $] >= 5.008 && $Config{useperlio};
   print $fh $ppd;
   close $fh;
 
@@ -121,10 +130,8 @@ sub _varchname {  # Copied from PPM.pm
   my ($self, $config) = @_;
   my $varchname = $config->{archname};
   # Append "-5.8" to architecture name for Perl 5.8 and later
-  if ($] >= 5.008) {
-      my $vstring = sprintf "%vd", $^V;
-      $vstring =~ s/\.\d+$//;
-      $varchname .= "-$vstring";
+  if (defined($^V) && ord(substr($^V,1)) >= 8) {
+    $varchname .= sprintf("-%d.%d", ord($^V), ord(substr($^V,1)));
   }
   return $varchname;
 }
@@ -138,7 +145,7 @@ sub _varchname {  # Copied from PPM.pm
 		 '<' => '&lt;',
 		);
   my $rx = join '|', keys %escapes;
-
+  
   sub _simple_xml_escape {
     $_[1] =~ s/($rx)/$escapes{$1}/go;
   }
@@ -152,6 +159,7 @@ __END__
 
 Module::Build::PPMMaker - Perl Package Manager file creation
 
+
 =head1 SYNOPSIS
 
   On the command line, builds a .ppd file:
